# Afkak Contributors

The following individuals, ordered by date of contribution, have helped make Afkak possible.

This project began as a port of the [kafka-python][kafka-python] library to Twisted.
At the time of the port these were the kafka-python contributors:

* David Arthur, [@mumrah](https://github.com/mumrah)
* Mahendra M, [@mahendra](https://github.com/mahendra)
* Omar, [@rdiomar](https://github.com/rdiomar) - RIP, Omar. 2014
* Marc Labbé, [@mrtheb](https://github.com/mrtheb)
* Ivan Pouzyrevsky, [@sandello](https://github.com/sandello)
* Thomas Dimson, [@cosbynator](https://github.com/cosbynator)
* Jim Lim, [@jimjh](https://github.com/jimjh)
* Zack Dever, [@zever](https://github.com/zever)
* StevenLeRoux, [@StevenLeRoux](https://github.com/StevenLeRoux)
* Saulius Žemaitaitis, [frgtn](https://github.com/frgtn)
* Vadim Graboys, [@vadimg](https://github.com/vadimg)
* Joe Crobak, [@jcrobak](https://github.com/jcrobak)
* Niek Sanders, [@nieksand](https://github.com/nieksand)
* Greg Bowyer, [@GregBowyer](https://github.com/GregBowyer)
* Evan Klitzke, [@eklitzke](https://github.com/eklitzke)
* [@anentropic](https://github.com/anentropic)
* Stephen Armstrong, [@stephenarmstrong](https://github.com/stephenarmstrong)
* Ben Frederickson, [@benfred](https://github.com/benfred)

Afkak contributors:

* Robert Thille, [@rthille](https://github.com/rthille)
* Tom Most, [@twm](https://github.com/twm)
* Julian Berman, [@Julian](https://github.com/Julian)
* Eli Most, [@mosteli](https://github.com/mosteli)
* Du Zheng, [@zsuzhengdu](https://github.com/zsuzhengdu)
* Jorge Cabrera, [@jcabmora](https://github.com/jcabmora)

Thanks, everyone!

[kafka-python]: https://github.com/mumrah/kafka-python
